Classifies the value in a field if it is one of the possible values considered for that field.
interpret_as_economic_journey_and_place_of_work(
mdr,
val,
value,
field_values = NULL
)A result structure.
A tibble row.
A transformed value.
A value.
A data frame to store associations between fields and values.